@@ -52,62 +52,28 @@ L<MARC::Record>
 =cut
 package Catmandu::Importer::MARC::Record;
 use Catmandu::Sane;
+use Catmandu::Importer::MARC::Decoder;
 use Moo;
 
 with 'Catmandu::Importer';
 
 has id        => (is => 'ro' , default => sub { '001' });
 has records   => (is => 'rw');
+has decoder   => (
+    is   => 'ro',
+    lazy => 1 , 
+    builder => sub {
+        Catmandu::Importer::MARC::Decoder->new;
+    } );
 
 sub generator {
     my ($self) = @_;
     my @records = @{$self->records};
 
     sub  {
-      $self->decode_marc(shift @records);
+      $self->decoder->decode(shift @records, $self->id);
     }
 }
 
-sub decode_marc {
-    my ($self, $record) = @_;
-    return unless eval { $record->isa('MARC::Record') };
-    my @result = ();
-
-    push @result , [ 'LDR' , undef, undef, '_' , $record->leader ];
-
-    for my $field ($record->fields()) {
-        my $tag  = $field->tag;
-        my $ind1 = $field->indicator(1);
-        my $ind2 = $field->indicator(2);
-
-        my @sf = ();
-
-        if ($field->is_control_field) {
-            push @sf , '_', $field->data;
-        }
-
-        for my $subfield ($field->subfields) {
-            push @sf , @$subfield;
-        }
-
-        push @result, [$tag,$ind1,$ind2,@sf];
-    }
-
-    my $sysid = undef;
-    my $id = $self->id;
-
-    if ($id =~ /^00/ && $record->field($id)) {
-        $sysid = $record->field($id)->data();
-    }
-    elsif ($id =~ /^(\d{3})([\da-zA-Z])$/) {
-        my $field = $record->field($1);
-        $sysid = $field->subfield($2) if ($field);
-    }
-    elsif (defined $id  && $record->field($id)) {
-        $sysid = $record->field($id)->subfield("a");
-    }
-
-    return { _id => $sysid , record => \@result };
-}
 
 1;
\ No newline at end of file
